@@ -209,6 +209,13 @@ turns on debugging output.  A numeric option can follow specifying
 the level (0, 1, or 2).  0 is none, 1 is basic, 2 is detailed.  
 Default:  B<1> (if I<-debug> is specified).
 
+One specific option (I<-omit>, added as of v1.45) permits omitting 
+specific submodules which are currently installed.  For example, to 
+NOT handle Youtube videos nor use the fallback "Anystream" module, 
+specify:  I<-omit> => I<"Youtube,Anystream">, which will cause 
+StreamFinder::Anystream and StreamFinder::Youtube to not be used 
+for the stream search.
+
 =item $station->B<get>(['playlist'])
 
 Returns an array of strings representing all stream URLs found.
@@ -420,7 +427,7 @@ use strict;
 use warnings;
 use vars qw(@ISA @EXPORT $VERSION);
 
-our $VERSION = '1.44';
+our $VERSION = '1.45';
 our $DEBUG = 0;
 
 require Exporter;
@@ -428,7 +435,7 @@ require Exporter;
 @ISA = qw(Exporter);
 @EXPORT = qw();
 my @supported_mods = (qw(Apple Bitchute Blogger Brighteon Castbox Google IHeartRadio
-		RadioNet Reciva Rumble SermonAudio Spreaker Tunein Vimeo Youtube));
+		RadioNet Reciva Rumble SermonAudio Spreaker Tunein Vimeo Youtube Anystream));
 
 my %haveit;
 
@@ -446,7 +453,21 @@ sub new
 	my $self = {};
 	return undef  unless ($url);
 
-	my @args = @_;
+	my $arg;
+	my @args = ();
+	while (@_) {
+		$arg = shift(@_);
+		if ($arg =~ /^\-?omit$/o) {   #ALLOW USER TO OMIT SPECIFIC INSTALLED SUBMODULE(S):
+			my @omitModules = split(/\,/, shift(@_));
+			foreach my $omit (@omitModules)
+			{
+				$haveit{$omit} = 0  if (defined($haveit{$omit}) && $haveit{$omit});
+			}
+		} else {
+			push @args, $arg;
+		}
+	}
+		
 	push @args, ('-debug', $DEBUG)  if ($DEBUG);
 	if ($haveit{'IHeartRadio'} && $url =~ m#\biheart(?:radio)?\.#i) {
 		return new StreamFinder::IHeartRadio($url, @args);
@@ -477,10 +498,13 @@ sub new
 	} elsif ($haveit{'SermonAudio'} && $url =~ m#\bsermonaudio\.com\/#) {
 		return new StreamFinder::SermonAudio($url, @args);
 	} elsif ($haveit{'Youtube'}) {  #DEFAULT TO youtube-dl SINCE SO MANY URLS ARE HANDLED THERE NOW.
-		return new StreamFinder::Youtube($url, @args);
-	} else {
-		return undef;
+		my $yt = new StreamFinder::Youtube($url, @args);
+		return $yt  if (defined($yt) && $yt && $yt->count() > 0);
 	}
+	if ($haveit{'Anystream'}) {  #SITE NOT SUPPORTED, TRY TO FIND ANY STREAM URLS WE CAN:
+		return new StreamFinder::Anystream($url, @args);
+	}
+	return undef;
 }
 
 1
